@@ -1,6 +1,6 @@
 test_that("viraltab() works", {
-  
-  library(tidyverse)
+  library(dplyr)
+  library(magrittr)
   library(baguette)
   library(kernlab)
   library(kknn)
@@ -9,6 +9,7 @@ test_that("viraltab() works", {
   library(glmnet)
   # Define the function to impute values in the undetectable range
   impute_undetectable <- function(column) {
+    set.seed(123)
     ifelse(column <= 40,
            rexp(sum(column <= 40), rate = 1/13) + 1,
            column)
@@ -19,13 +20,14 @@ test_that("viraltab() works", {
   viral_imputed <- viral %>%
     mutate(across(starts_with("vl"), ~impute_undetectable(.x)))
   traindata <- viral_imputed
-  semilla <- 123
+  semilla <- 1501
   target <- "cd_2022"
   viralvars <- c("vl_2019", "vl_2021", "vl_2022")
   logbase <- 10
   pliegues <- 2
   repeticiones <- 1
   rejilla <- 1
-  expect_snapshot(print(viraltab(traindata, semilla, target, viralvars, logbase, pliegues, repeticiones, rejilla, rank_output = TRUE)))
+  set.seed(123)
+  expect_snapshot(viraltab(traindata, semilla, target, viralvars, logbase, 
+                           pliegues, repeticiones, rejilla, rank_output = TRUE))
 })
-
